# tpp7

Un package python pour les TP de Physique de l'Université de Paris-Diderot, maintenant Université Paris Cité.

Ce package la librairie python Oscillo 

## Installation

Ce paquet repose sur une installation python > 3.6

Il a en particulier été testé à partir de (miniconda)[https://docs.conda.io/en/latest/miniconda.html]

Il nécessite les paquets suivants :  `numpy, scipy, matplotlib, python-usbtmc, pandas, pyusb`
L'application d'utilisation de la librairie Oscillo requière également l'installation de `pyqt`

qu'il est vraisemblablement préférable d'installer avec le gestionnaire natif de votre installation python (python-usbtmc n'est pas disponible via conda):

    conda update -c conda-forge numpy scipy matplotlib pandas pyusb pyqt
    pip install --upgrade python-usbtmc tpp7

## linfitxy n'est plus distribué via ce paquet...

(https://pypi.org/project/fitutils/)[https://pypi.org/project/fitutils/]
(https://github.com/M-A-Verdier/Fitutils)[https://github.com/M-A-Verdier/Fitutils]
 
Il est cependant installé comme une dépendance.

### Oscillo
Oscillo est destiné à récupérer les données des oscilloscopes utilisés dans les salles de TP.
Il permet également de faire une copie d'écran.
Il est constitué d'une librairie permet d'utiliser facilement les fonctions de base par exemple dans un environnement comme Jupyter.
Il donne également accès à une application (en QT5) qui permet également facilement d'importer les données et de faire une copie d'écran.

Les oscilloscopes pris en charge pour le moment sont : 
- Tektronix
    - TDS
        - "1001B": (0x0699, 0x0362),
        - "1001C-EDU": (0x0699, 0x03aa),
        - "2004B": (0x0699, 0x0365),
        - "2024B": (0x0699, 0x036a), # Non testé
    - TBS
        - "1064": (0x0699, 0x03b3),
          "1104": (0x0699, 0x03b4),  
        - "1052B-EDU": {0x0699, 0x0368},
        
- Keyseight
    - DSO-X
        - "1102A": (0x2a8d, 0x1787),

- Agilent
    - __ 
        - "DSO1024A": (0x0957, 0x0588),

Il est sans doute assez facile d'utiliser d'autres modèles d'oscilloscopes.


# Installaion
- Auteur : Olivier Cardoso
- Email : Olivier.Cardoso@u-paris.fr

   
